==> videosdk-0.0.1.tar.gz: videosdk-0.0.1/videosdk/videosdk.py <==
from asyncio import AbstractEventLoop
from dataclasses import dataclass
import random
import string
from typing import Any, Dict, Optional, TypedDict, Union

from .room_client import RoomClient, RoomClientConfig
from .participant import Participant, ParticipantConfig
from .meeting import Meeting
from .exceptions import MeetingInitializationError, InvalidMeetingConfigError

SIGNALLING_BASE_URL = "api.videosdk.live"


@dataclass
class MeetingConfig(TypedDict, total=False):
    meeting_id: Optional[str]
    custom_camera_video_track: Optional[Any]
    custom_microphone_audio_track: Optional[Any]
    auto_consume: bool
    preferred_protocol: Optional[str]
    mode: Optional[str]
    participant_id: Optional[str]
    name: Optional[str]
    mic_enabled: bool
    webcam_enabled: bool
    meta_data: Optional[Dict[str, Any]]
    chat_enabled: bool
    signaling_base_url: Optional[str]
    debug_mode: bool
    token: str
    loop: AbstractEventLoop


class VideoSDK:
    @staticmethod
    def init_meeting(**kwargs: Union[MeetingConfig, Any]):
        meeting_id: Optional[str] = kwargs.get("meeting_id")
        custom_camera_video_track: Optional[Any] = kwargs.get(
            "custom_camera_video_track"
        )
        custom_microphone_audio_track: Optional[Any] = kwargs.get(
            "custom_microphone_audio_track"
        )
        auto_consume: bool = kwargs.get("auto_consume", True)
        preferred_protocol: Optional[str] = kwargs.get("preferred_protocol")
        mode: Optional[str] = kwargs.get("mode")
        participant_id: Optional[str] = kwargs.get("participant_id")
        name: Optional[str] = kwargs.get("name")
        mic_enabled: bool = kwargs.get("mic_enabled", True)
        webcam_enabled: bool = kwargs.get("webcam_enabled", True)
        meta_data: Optional[Dict[str, Any]] = kwargs.get("meta_data")
        chat_enabled: bool = kwargs.get("chat_enabled", True)
        signaling_base_url: Optional[str] = kwargs.get(
            "signaling_base_url", SIGNALLING_BASE_URL
        )
        debug_mode: bool = kwargs.get("debug_mode", True)
        token: Optional[str] = kwargs.get("token")
        loop: AbstractEventLoop = kwargs.get("loop")

        if not token:
            raise InvalidMeetingConfigError("token is required")

        if not meeting_id:
            raise InvalidMeetingConfigError(
                "'meeting_id' is empty, please verify it or generate a new meeting_id using the API."
            )

        peer_id = (
            participant_id
            if participant_id
            else "".join(random.choices(string.ascii_lowercase + string.digits, k=8))
        )
        display_name = (
            name
            if name
            else "".join(
                random.choices(string.ascii_lowercase + string.digits, k=6)
            ).toLowerCase()
        )

        if not preferred_protocol:
            preferred_protocol = "UDP_ONLY"

        if preferred_protocol not in ["UDP_ONLY", "UDP_OVER_TCP"]:
            preferred_protocol = "UDP_ONLY"

        if not mode:
            mode = "CONFERENCE"

        if mode not in ["CONFERENCE", "VIEWER"]:
            raise InvalidMeetingConfigError(
                f'"mode" can only be either "CONFERENCE" or "VIEWER"'
            )

        if meta_data is not None and not isinstance(meta_data, dict):
            raise InvalidMeetingConfigError('"meta_data" can only be a dictionary.')

        default_camera_index = 0

        room_client_config = RoomClientConfig(
            room_id=meeting_id,
            peer_id=peer_id,
            secret=token,
            display_name=display_name,
            mode=mode,
            produce=True,
            consume=True,
            use_sharing_simulcast=True,
            datachannel=chat_enabled,
            mic_enabled=mic_enabled,
            webcam_enabled=webcam_enabled,
            custom_camera_video_track=custom_camera_video_track,
            custom_microphone_audio_track=custom_microphone_audio_track,
            auto_consume=auto_consume,
            preferred_protocol=preferred_protocol,
            signaling_base_url=signaling_base_url,
            meta_data=meta_data,
            default_camera_index=default_camera_index,
            debug_mode=debug_mode,
            loop=loop,
        )

        room_client = RoomClient(**room_client_config)

        participant_config = ParticipantConfig(
            id=peer_id,
            display_name=display_name,
            local=True,
            mode=mode,
            meta_data=meta_data,
            room_client=room_client,
        )

        local_participant = Participant(**participant_config)

        return Meeting(meeting_id, local_participant, room_client)

==> videosdk-0.0.2.tar.gz: videosdk-0.0.2/videosdk/videosdk.py <==
from asyncio import AbstractEventLoop
from dataclasses import dataclass
import random
import string
from typing import Any, Dict, Optional, TypedDict, Union
from .room_client import RoomClient, RoomClientConfig
from .participant import Participant, ParticipantConfig
from .meeting import Meeting
from .exceptions import MeetingInitializationError, InvalidMeetingConfigError

SIGNALLING_BASE_URL = "api.videosdk.live"


@dataclass
class MeetingConfig(TypedDict, total=False):
    meeting_id: Optional[str]
    custom_camera_video_track: Optional[Any]
    custom_microphone_audio_track: Optional[Any]
    auto_consume: bool
    preferred_protocol: Optional[str]
    mode: Optional[str]
    participant_id: Optional[str]
    name: Optional[str]
    mic_enabled: bool
    webcam_enabled: bool
    meta_data: Optional[Dict[str, Any]]
    chat_enabled: bool
    signaling_base_url: Optional[str]
    debug_mode: bool
    token: str
    loop: AbstractEventLoop


class VideoSDK:
    @staticmethod
    def init_meeting(**kwargs: Union[MeetingConfig, Any]) -> Meeting:
        meeting_id: Optional[str] = kwargs.get("meeting_id")
        custom_camera_video_track: Optional[Any] = kwargs.get(
            "custom_camera_video_track"
        )
        custom_microphone_audio_track: Optional[Any] = kwargs.get(
            "custom_microphone_audio_track"
        )
        auto_consume: bool = kwargs.get("auto_consume", True)
        preferred_protocol: Optional[str] = kwargs.get("preferred_protocol")
        mode: Optional[str] = kwargs.get("mode")
        participant_id: Optional[str] = kwargs.get("participant_id")
        name: Optional[str] = kwargs.get("name")
        mic_enabled: bool = kwargs.get("mic_enabled", True)
        webcam_enabled: bool = kwargs.get("webcam_enabled", True)
        meta_data: Optional[Dict[str, Any]] = kwargs.get("meta_data")
        chat_enabled: bool = kwargs.get("chat_enabled", True)
        signaling_base_url: Optional[str] = kwargs.get(
            "signaling_base_url", SIGNALLING_BASE_URL
        )
        debug_mode: bool = kwargs.get("debug_mode", True)
        token: Optional[str] = kwargs.get("token")
        loop: AbstractEventLoop = kwargs.get("loop")

        if not token:
            raise InvalidMeetingConfigError("token is required")

        if not meeting_id:
            raise InvalidMeetingConfigError(
                "'meeting_id' is empty, please verify it or generate a new meeting_id using the API."
            )

        peer_id = (
            participant_id
            if participant_id
            else "".join(random.choices(string.ascii_lowercase + string.digits, k=8))
        )
        display_name = (
            name
            if name
            else "".join(
                random.choices(string.ascii_lowercase + string.digits, k=6)
            ).toLowerCase()
        )

        if not preferred_protocol:
            preferred_protocol = "UDP_ONLY"

        if preferred_protocol not in ["UDP_ONLY", "UDP_OVER_TCP"]:
            preferred_protocol = "UDP_ONLY"

        if not mode:
            mode = "CONFERENCE"

        if mode not in ["CONFERENCE", "VIEWER"]:
            raise InvalidMeetingConfigError(
                f'"mode" can only be either "CONFERENCE" or "VIEWER"'
            )

        if meta_data is not None and not isinstance(meta_data, dict):
            raise InvalidMeetingConfigError(
                '"meta_data" can only be a dictionary.')

        default_camera_index = 0

        room_client_config = RoomClientConfig(
            room_id=meeting_id,
            peer_id=peer_id,
            secret=token,
            display_name=display_name,
            mode=mode,
            produce=True,
            consume=True,
            use_sharing_simulcast=True,
            datachannel=chat_enabled,
            mic_enabled=mic_enabled,
            webcam_enabled=webcam_enabled,
            custom_camera_video_track=custom_camera_video_track,
            custom_microphone_audio_track=custom_microphone_audio_track,
            auto_consume=auto_consume,
            preferred_protocol=preferred_protocol,
            signaling_base_url=signaling_base_url,
            meta_data=meta_data,
            default_camera_index=default_camera_index,
            debug_mode=debug_mode,
            loop=loop,
        )

        room_client = RoomClient(**room_client_config)

        participant_config = ParticipantConfig(
            id=peer_id,
            display_name=display_name,
            local=True,
            mode=mode,
            meta_data=meta_data,
            room_client=room_client,
        )

        local_participant = Participant(**participant_config)

        return Meeting(meeting_id, local_participant, room_client)
